@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: egg-toolbar-editor.c 832 2007-11-03 22:14:56Z friemann $
+ *  $Id: egg-toolbar-editor.c 929 2009-02-19 14:49:56Z friemann $
  */
 
 #include "config.h"
@@ -25,14 +25,6 @@
 
 #include <string.h>
 #include <libxml/tree.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkeventbox.h>
-#include <gtk/gtkdnd.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkhbox.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
@@ -92,7 +84,7 @@ compare_items (gconstpointer a,
                                   "egg-collate-key");
   char *key2 = g_object_get_data (G_OBJECT (item2),
                                   "egg-collate-key");
-  
+
   return strcmp (key1, key2);
 }
 
@@ -186,14 +178,14 @@ egg_toolbar_editor_set_model (EggToolbarEditor *t,
       if (G_UNLIKELY (priv->model == model)) return;
 
       egg_toolbar_editor_disconnect_model (t);
-      g_object_unref (priv->model); 
+      g_object_unref (priv->model);
     }
 
   priv->model = g_object_ref (model);
 
   update_editor_sheet (t);
-  
-  priv->sig_handlers[SIGNAL_HANDLER_ITEM_ADDED] = 
+
+  priv->sig_handlers[SIGNAL_HANDLER_ITEM_ADDED] =
     g_signal_connect_object (model, "item_added",
 			     G_CALLBACK (item_added_or_removed_cb), t, 0);
   priv->sig_handlers[SIGNAL_HANDLER_ITEM_REMOVED] =
@@ -329,7 +321,7 @@ drag_data_get_cb (GtkWidget          *widget,
 
   target = g_object_get_data (G_OBJECT (widget), "egg-item-name");
   g_return_if_fail (target != NULL);
-  
+
   gtk_selection_data_set (selection_data, selection_data->target, 8,
 			  (const guchar *) target, strlen (target));
 }
@@ -365,9 +357,9 @@ set_drag_cursor (GtkWidget *widget)
 {
   GdkCursor *cursor;
   GdkScreen *screen;
-  
+
   screen = gtk_widget_get_screen (widget);
-  
+
   cursor = gdk_cursor_new_for_display (gdk_screen_get_display (screen),
 				       GDK_HAND2);
   gdk_window_set_cursor (widget->window, cursor);
@@ -484,16 +476,16 @@ editor_create_item_from_name (EggToolbarEditor *editor,
   const char *item_name;
   char *short_label;
   const char *collate_key;
-  
+
   if (strcmp (name, "_separator") == 0)
     {
       GtkWidget *icon;
-      
+
       icon = _egg_editable_toolbar_new_separator_image ();
       short_label = _("Separator");
       item_name = g_strdup (name);
       collate_key = g_utf8_collate_key (short_label, -1);
-      item = editor_create_item (editor, GTK_IMAGE (icon), 
+      item = editor_create_item (editor, GTK_IMAGE (icon),
                                  short_label, drag_action);
     }
   else
@@ -501,7 +493,7 @@ editor_create_item_from_name (EggToolbarEditor *editor,
       GtkAction *action;
       GtkWidget *icon;
       char *stock_id, *icon_name = NULL;
-      
+
       action = find_action (editor, name);
       g_return_val_if_fail (action != NULL, NULL);
 
@@ -528,12 +520,12 @@ editor_create_item_from_name (EggToolbarEditor *editor,
       g_free (stock_id);
       g_free (icon_name);
     }
-  
+
   g_object_set_data_full (G_OBJECT (item), "egg-collate-key",
                           (gpointer) collate_key, g_free);
   g_object_set_data_full (G_OBJECT (item), "egg-item-name",
                           (gpointer) item_name, g_free);
-  
+
   return item;
 }
 
@@ -545,10 +537,10 @@ append_table (GtkTable *table, GList *items, gint y, gint width)
       gint x = 0, height;
       GtkWidget *alignment;
       GtkWidget *item;
-  
+
       height = g_list_length (items) / width + 1;
       gtk_table_resize (table, height, width);
-      
+
       if (y > 0)
         {
           item = gtk_hseparator_new ();
@@ -556,10 +548,10 @@ append_table (GtkTable *table, GList *items, gint y, gint width)
           gtk_container_add (GTK_CONTAINER (alignment), item);
           gtk_widget_show (alignment);
           gtk_widget_show (item);
-          
+
           gtk_table_attach_defaults (table, alignment, 0, width, y-1, y+1);
         }
-      
+
       for (; items != NULL; items = items->next)
         {
           item = items->data;
@@ -567,7 +559,7 @@ append_table (GtkTable *table, GList *items, gint y, gint width)
           gtk_container_add (GTK_CONTAINER (alignment), item);
           gtk_widget_show (alignment);
           gtk_widget_show (item);
-          
+
           if (x >= width)
             {
               x = 0;
@@ -576,7 +568,7 @@ append_table (GtkTable *table, GList *items, gint y, gint width)
           gtk_table_attach_defaults (table, alignment, x, x+1, y, y+1);
           x++;
         }
-      
+
       y++;
     }
   return y;
@@ -592,7 +584,7 @@ update_editor_sheet (EggToolbarEditor *editor)
   GtkWidget *viewport;
 
   g_return_if_fail (EGG_IS_TOOLBAR_EDITOR (editor));
-  
+
   /* Create new table. */
   table = gtk_table_new (0, 0, TRUE);
   editor->priv->table = table;
@@ -602,7 +594,7 @@ update_editor_sheet (EggToolbarEditor *editor)
   gtk_drag_dest_set (table, GTK_DEST_DEFAULT_ALL,
 		     dest_drag_types, G_N_ELEMENTS (dest_drag_types),
                      GDK_ACTION_MOVE | GDK_ACTION_COPY);
-  
+
   /* Build two lists of items (one for copying, one for moving). */
   items = egg_toolbars_model_get_name_avail (editor->priv->model);
   while (items->len > 0)
@@ -610,10 +602,10 @@ update_editor_sheet (EggToolbarEditor *editor)
       GtkWidget *item;
       const char *name;
       gint flags;
-      
+
       name = g_ptr_array_index (items, 0);
       g_ptr_array_remove_index_fast (items, 0);
-      
+
       flags = egg_toolbars_model_get_name_flags (editor->priv->model, name);
       if ((flags & EGG_TB_MODEL_NAME_INFINITE) == 0)
         {
@@ -633,11 +625,11 @@ update_editor_sheet (EggToolbarEditor *editor)
   y = 0;
   y = append_table (GTK_TABLE (table), to_move, y, 4);
   y = append_table (GTK_TABLE (table), to_copy, y, 4);
-  
+
   g_list_free (to_move);
   g_list_free (to_copy);
   g_ptr_array_free (items, TRUE);
-  
+
   /* Delete old table. */
   viewport = GTK_BIN (editor->priv->scrolled_window)->child;
   if (viewport)
@@ -645,7 +637,7 @@ update_editor_sheet (EggToolbarEditor *editor)
       gtk_container_remove (GTK_CONTAINER (viewport),
                             GTK_BIN (viewport)->child);
     }
-  
+
   /* Add table to window. */
   gtk_scrolled_window_add_with_viewport
     (GTK_SCROLLED_WINDOW (editor->priv->scrolled_window), table);
